==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Siguiente");
define("_SEARCHRESULTS","Resultados de la Bsqueda");
define("_PAGE","pgina(s) ");
define("_RETURNTO","Volver a");
define("_DEACTIVATE","Desactivar");
define("_ACTIVATE","Activar");
define("_ENCYCLOPEDIA","Enciclopedia");
define("_NOCONTENTFORLETTER","Disculpa, no existe ningn contenido por la letra");
define("_ENCYSELECTLETTER","Por Favor selecciona una letra de la siguiente lista para consultar los trminos:");
define("_COPYRIGHT","Copyright &copy; por $sitename. Todos los Derechos Reservados.");
define("_YOURADMINENCY","Eres Administrador, esta enciclopedia no est activada!");
define("_ENCYNOTACTIVE","Disculpa, esta enciclopedia no est activada en este momento.");
define("_AVAILABLEENCYLIST","Lista de las Enciclopedias disponibles en");
define("_YOURADMININACTIVELIST","Eres Administrador: Lista de las Enciclopedias Inactivas:");
define("_NORESULTSTEXT","No hay Resultados en el Texto de los Trminos...");
define("_NORESULTSTITLE","No hay Resultados en Ttulo de los Trminos...");
define("_SEARCHRESULTSFOR","Resultados de la Bsqueda de:");
define("_SEARCHNOTCOMPLETE","Opciones de la bsqueda no est completas. Por Favor intenta de nuevo.");
define("_RESULTSINTERMTITLE","Resultados en el ttulo de los trminos:");
define("_RESULTSINTERMTEXT","Resultados en el texto de los trminos:");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Siguiente");
define("_SEARCHRESULTS","Resultados de la Bsqueda");
define("_PAGE","pgina(s) ");
define("_RETURNTO","Volver a");
define("_DEACTIVATE","Desactivar");
define("_ACTIVATE","Activar");
define("_ENCYCLOPEDIA","Enciclopedia");
define("_NOCONTENTFORLETTER","Disculpa, no existe ningn contenido por la letra");
define("_ENCYSELECTLETTER","Por Favor selecciona una letra de la siguiente lista para consultar los trminos:");
define("_COPYRIGHT","Copyright &copy; por $sitename. Todos los Derechos Reservados.");
define("_YOURADMINENCY","Eres Administrador, esta enciclopedia no est activada!");
define("_ENCYNOTACTIVE","Disculpa, esta enciclopedia no est activada en este momento.");
define("_AVAILABLEENCYLIST","Lista de las Enciclopedias disponibles en");
define("_YOURADMININACTIVELIST","Eres Administrador: Lista de las Enciclopedias Inactivas:");
define("_NORESULTSTEXT","No hay Resultados en el Texto de los Trminos...");
define("_NORESULTSTITLE","No hay Resultados en Ttulo de los Trminos...");
define("_SEARCHRESULTSFOR","Resultados de la Bsqueda de:");
define("_SEARCHNOTCOMPLETE","Opciones de la bsqueda no est completas. Por Favor intenta de nuevo.");
define("_RESULTSINTERMTITLE","Resultados en el ttulo de los trminos:");
define("_RESULTSINTERMTEXT","Resultados en el texto de los trminos:");

?>
